# indicator-rr-oracle

fake future-looking risk-reward 'oracle' indicator for evaluating/backtesting quant strategies. does *not* actually predict/forecast future.

experimental, use at your own risk.

## Installation

```sh
npm i indicator-rr-oracle
```

## Usage 

```javascript
var candles = require('candles-sample-aapl').loadNMinuteCandles(60).slice(50);

var calculateRR = require('indicator-rr-oracle').calculateRR;
var periods = 15;
//        calculateRR(candles, periods=15, rrLimit = 50, includeRecentNCandles = false)
candles = calculateRR(candles, periods);

console.log(candles.slice(-16)[0]); //note that by default the last 15 candles dont get augmented, so we take the 16th from the end

// {
//     date: '2022-11-30T19:00:00.000Z',
//     open: 144.42,
//     high: 146.445,
//     low: 144.41,
//     close: 146.03,
//     bid: 144.4,
//     ask: 144.42,
//     volume: 16329318,
//     nSrcCandles: 60,
//     rr_15: {
//         lossGainAbsolute: [ -0.2400000000000091, 2.9505000000000052 ], //dollar amounts
//         lossGainSTD: [ -0.15215899604364846, 1.8706046576115358 ], // +/- how many standard deviations
//         lossGainNormalized: [ -0.0016434979113881332, 0.020204752448127132 ], // +/- dollars/candleClosePrice
//         lossGainFraction: [ 0.9983565020886118, 1.020204752448127 ], // eg [lowPrice/candleClosePrice , highPrice/candleClosePrice]
//         lossGainFractionLog2: [ -0.0023730168451682747, 0.02885872640951597 ], //log2 of above, similar to normalized 
//         riskReward: 12.293749999999555, // abs gain / abs loss
//         riskRewardLog2: 3.6198531473911157,
//         futureHighIndex: 2, //periods until high
//         futureLowIndex: 10 //periods until low
//     }
// }



//the rest of this code is just for charting ...

//quickly chart the result by adding the indicator
// to the price of the first candle in the chart
var {drawChartForCandles,saveChartForCandles} = require('ohlc-chart-simple');

candles = candles.map(function(candle,index){
    //add shifted sqrt of signal to the graph as an indicator
    if(candle.rr_15){
        var signalRR = candles[0].close + Math.sqrt(candle.rr_15.riskReward);
        //var signalRR = candles[0].close + candle.rr_15.riskRewardLog2; 
        var signalRR1 = candles[0].close + 1; //break-even line 
        candle.indicators = {
            "RR15_LINE": signalRR,
            "RR15_LINE_color": [0,0,255],
            "RR15_LINE_thickness": 0,
            "RR15_1LINE": signalRR1,
            "RR15_1LINE_color": [0,0,0],
            "RR15_1LINE_thickness": 0,
        }
    }

    return candle;
});

var config = {
    w: Math.floor(1024/2),
    h: Math.floor(700/2),
    profileBucketsTotal: 64,
    profileBucketsWidth: 16,
    volumeBarsHeight: 64,
    bgColor: [255,255,255],

    //alternative to volume profile: arbitrary kernel density histogram
    kdePrices: candles.map(c=>[c.low, 1]), //[value, weight]
    // kdeBandwidthDollars: 0.01,
    kdeBandwidthPercent: 1.00,
    kdeIsGaussian: true, //false == kernel is triangular
    kdeColor: [0,0,255],

    skipDrawOhlcBars: false,
    skipDrawIndicators: false,
    skipDrawLegend: false,
    expandLegendText: false,
    expandTitle: false,
    expandPrice: false,
    skipDrawDate: true,
    skipDrawPrice: false,
    skipDrawPriceBars: false,
    title: "AAPL",
    filename: "./candlestick-chart.png",
}

saveChartForCandles(candles, config);
```

![chart](https://i.imgur.com/2JQLJKR.png)

^with sqrt(risk/reward). note that the price-value of the indicator/break-even line is not meaningful.

![chart](https://i.imgur.com/CQaxHXH.png)

^with log2(r/r). note that the price-value of the indicator/break-even line is not meaningful.

[![stonks](https://i.imgur.com/UpDxbfe.png)](https://www.npmjs.com/~stonkpunk)



